@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
 
+"""Simulation of genomes."""
+
 import os
 
-from asymmetree.datastructures.PhyloTree import PhyloTree
+from tralda.datastructures.Tree import Tree
+
 import asymmetree.treeevolve as te
 import asymmetree.seqevolve as se
 from asymmetree.file_io.SeqFileIO import write_alignment, write_fasta
@@ -15,9 +18,20 @@ __author__ = 'David Schaller'
 class GenomeSimulator:
     
     def __init__(self, species_tree, outdir=None):
+        """
+        Parameters
+        ----------
+        species_tree : Tree
+            The species tree along which gene trees are simulated.
+        outdir : str, optional
+            The path to a directory into which the results of the simulation
+            (serialized trees, one fasta file per genome, one 'true' alignement
+            per gene family). The default is None, in which case nothing is
+            saved to file.
+        """
         
-        if not isinstance(species_tree, PhyloTree):
-            raise TypeError("species tree must be of type 'PhyloTree'")
+        if not isinstance(species_tree, Tree):
+            raise TypeError("species tree must be of type 'Tree'")
         
         self.S = species_tree
         self.outdir = outdir
@@ -27,7 +41,7 @@ class GenomeSimulator:
             self.S.serialize(self._path('species_tree.json'), mode='json')
             
         self.true_gene_trees = []
-        self.observable_gene_trees = []
+        self.pruned_gene_trees = []
         
     
     def _check_outdir(self):
@@ -49,27 +63,41 @@ class GenomeSimulator:
         return os.path.join(self.outdir, *args)
             
     
-    def simulate_gene_trees(self, N,
+    def simulate_gene_trees(self, n,
                             **kwargs):
+        """Simulate gene trees.
         
-        self.number_of_families = N
+        Simulates the 'true gene trees' which still contain the loss events as
+        well as the 'pruned gene trees' in which the loss branches are
+        removed.
         
-        self.true_gene_trees = te.simulate_gene_trees(self.S, N=N, **kwargs)
-        if N == 1:
-            self.true_gene_trees = [self.true_gene_trees]
+        Parameters
+        ----------
+        n : int
+            Number of gene trees to be simulated.
+        kwargs : optional
+            See function 'gene_trees' in 'treeevolve' subpackage or 
+            documentation.
+        """
         
-        self.observable_gene_trees = [te.observable_tree(tree)
-                                      for tree in self.true_gene_trees]
+        self.number_of_families = n
+        
+        self.true_gene_trees = te.gene_trees(self.S, n=n, **kwargs)
+        
+        self.pruned_gene_trees = [te.prune_losses(tree)
+                                  for tree in self.true_gene_trees]
         
         # sequences should be emptied here if methods were called before
         if hasattr(self, 'sequence_dicts'):
             self.sequence_dicts.clear()
         
         if self.outdir:
-            for i in range(N):
+            for i in range(n):
                 filename = self._path('true_gene_trees',
                                       'gene_tree{}.json'.format(i))
                 self.true_gene_trees[i].serialize(filename, mode='json')
+        
+        return self.true_gene_trees, self.pruned_gene_trees
                 
     
     def simulate_sequences(self, subst_model,
@@ -80,6 +108,39 @@ class GenomeSimulator:
                            write_fastas=True,
                            write_alignments=True,
                            **kwargs):
+        """Simulate sequences along the (pruned) gene trees.
+        
+        Parameters
+        ----------
+        subst_model : SubstModel
+            Substitution model.
+        root_genome : list, optional
+            List of sequences for the roots of the gene trees, must contain the
+            same number of str sequences as trees that were simulated. 
+            The sequences must be compatible with the specified substitution 
+            model (model_type='n'/'a'). The default is None, in which case new
+            sequences are generated at random.
+        length_distr : tuple, optional
+            Distribution of the length of the root sequences if root genome is
+            not supplied. See documentation for available options.
+        min_length : int, optional
+            Minimal length at which the distribution of lengths is truncated;
+            must be less than the mean of this distribution. The default is 10.
+        max_length : int, optional
+            Maximal length at which the distribution of lengths is truncated;
+            must be less than the mean of this distribution. The default is
+            None, in which case the distribution is not truncated.
+        write_fastas : bool, optional
+            If True and an output directory was speci ed, write the sequences
+            (one file per species) into the directory 'fasta_files' in the
+            output directory. The default is True.
+        write_alignments : bool, optional
+            If True and an output directory was speci ed, write the true 
+            alignments (one file per gene tree) into the directory 'alignments'
+            in the output directory. The default is True.
+        kwargs : optional
+            See class 'Evolver' in the 'seqevolve' subpackage or documentation.
+        """
         
         self.subst_model = subst_model
         
@@ -105,13 +166,13 @@ class GenomeSimulator:
         
         for i in range(self.number_of_families):
             
-            OGT = self.observable_gene_trees[i]
+            PGT = self.pruned_gene_trees[i]
             
             if root_genome:
-                evolver.evolve_along_tree(OGT, start_seq=root_genome[i].upper())
+                evolver.evolve_along_tree(PGT, start_seq=root_genome[i].upper())
                 
             else:
-                evolver.evolve_along_tree(OGT, start_length=self.sampler.draw())
+                evolver.evolve_along_tree(PGT, start_length=self.sampler())
                 
             self.sequence_dicts.append(evolver.sequences)
             
@@ -129,7 +190,7 @@ class GenomeSimulator:
         if not self.outdir:
             raise RuntimeError('no output directory specified for alignments')        
         
-        alg_builder = se.AlignmentBuilder(self.observable_gene_trees[family_id],
+        alg_builder = se.AlignmentBuilder(self.pruned_gene_trees[family_id],
                                           self.sequence_dicts[family_id],
                                           self.subst_model.alphabet,
                                           include_inner=False)
@@ -149,13 +210,13 @@ class GenomeSimulator:
         if not self.outdir:
             raise RuntimeError('no output directory specified for fasta files')
         
-        # list of all species IDs
+        # list of all species labels
         if include_inner:
-            species = [v.ID for v in self.S.preorder()]
+            species = [v.label for v in self.S.preorder()]
         else:
-            species = [v.ID for v in self.S.preorder() if not v.children]
+            species = [v.label for v in self.S.preorder() if not v.children]
         
-        # labeled sequences sorted by color/species
+        # labeled sequences sorted by species
         sorted_seqs = {s: [] for s in species}
         
         for i in range(self.number_of_families):
@@ -167,7 +228,7 @@ class GenomeSimulator:
                 
                 label = self._compose_label(node, i)
                 sequence = self.subst_model.to_sequence(evoseq)
-                sorted_seqs[node.color].append( (label, sequence) )
+                sorted_seqs[node.reconc].append( (label, sequence) )
                 
         for spec, sequences in sorted_seqs.items():
             basename = '{}.f{}a'.format(spec, self.subst_model.model_type)
@@ -177,4 +238,4 @@ class GenomeSimulator:
     
     def _compose_label(self, node, family_id):
         
-        return 'fam{}gene{}spec{}'.format(family_id, node.label, node.color)
\ No newline at end of file
+        return 'fam{}gene{}spec{}'.format(family_id, node.label, node.reconc)
