@@ -1,11 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Evolving sequence.
-
-Classes in this module:
-    - EvoSeqElement     (site element in an evolving sequence)
-    - EvoSeq            (evolving sequence)
+Data structure for evolving sequences.
 """
 
 from enum import Enum, auto
@@ -19,14 +15,15 @@ __author__ = 'David Schaller'
 
 
 class State(Enum):
+    """State of the sites in evolving sequences."""
     
     ROOT       = auto()
     INSERTION  = auto()
     INHERITED  = auto()
 
 
-class EvoSeqElement(DLListNode):
-    """Site element in an evolving sequence."""
+class EvoSeqNode(DLListNode):
+    """Site in an evolving sequence."""
     
     __slots__ = ('status', 'site_id', 'parent_el', 'rate_class', 'rate_factor')
     
@@ -66,11 +63,11 @@ class EvoSeq(DLList):
     def append(self, value, status, site_id, parent_el=None,
                rate_class=0, rate_factor=1.0):
         
-        new_end = EvoSeqElement(value, status, site_id,
-                                prev_node=self._last,
-                                parent_el=parent_el,
-                                rate_class=rate_class,
-                                rate_factor=rate_factor)
+        new_end = EvoSeqNode(value, status, site_id,
+                             prev_node=self._last,
+                             parent_el=parent_el,
+                             rate_class=rate_class,
+                             rate_factor=rate_factor)
         if self._last:
             self._last._next = new_end
         self._last = new_end
@@ -83,11 +80,11 @@ class EvoSeq(DLList):
     def append_left(self, value, status, site_id, parent_el=None,
                     rate_class=0, rate_factor=1.0):
         
-        new_start = EvoSeqElement(value, status, site_id,
-                                  next_node=self._first,
-                                  parent_el=parent_el,
-                                  rate_class=rate_class,
-                                  rate_factor=rate_factor)
+        new_start = EvoSeqNode(value, status, site_id,
+                               next_node=self._first,
+                               parent_el=parent_el,
+                               rate_class=rate_class,
+                               rate_factor=rate_factor)
         if self._first:
             self._first._prev = new_start
         self._first = new_start
@@ -107,12 +104,12 @@ class EvoSeq(DLList):
                                       rate_factor=rate_factor)
             
         else:
-            new_element = EvoSeqElement(value, status, site_id,
-                                        prev_node=element,
-                                        next_node=element._next,
-                                        parent_el=parent_el,
-                                        rate_class=rate_class,
-                                        rate_factor=rate_factor)
+            new_element = EvoSeqNode(value, status, site_id,
+                                     prev_node=element,
+                                     next_node=element._next,
+                                     parent_el=parent_el,
+                                     rate_class=rate_class,
+                                     rate_factor=rate_factor)
             new_element._next._prev = new_element
             element._next = new_element
             self._count += 1
